﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Pixoneer.NXDL;  // 추가

namespace XDL_GeoPosition
{
    /// <summary>
    /// MainWindow.xaml에 대한 상호 작용 논리
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Closed(object sender, EventArgs e)
        {
            Pixoneer.NXDL.Xfn.Close();  // 코드 추가
        }

        private void buttonCalcPositionByBearingAndDistance_Click(object sender, RoutedEventArgs e)
        {
            // 지구의 특저 기준점으로부터 북쪽으로부터 시계방향의 방위각과 임의의 거리에 해당하는 지점을 계산

            // 1. 기준점 설정
            XAngle lon1 = XAngle.FromDegree(127);
            XAngle lat1 = XAngle.FromDegree(36);

            // 2. 북쪽으로부터 방위각 설정
            XAngle bearing = XAngle.FromDegree(45);

            // 3. 거리 설정 (unit : meter)
            double dist = 10000;

            // 4. 결과값에 해당하는 위경도 값을 얻을 XAngle생성
            XAngle lon2 = new XAngle();
            XAngle lat2 = new XAngle();

            // 5. CalcPosByBearingAndDist함수를 통해 지점 계산
            XAngle ang = Xfn.CalcPosByBearingAndDist(lon1, lat1, bearing, dist, ref lon2, ref lat2);

            Console.WriteLine("Position : " + lon2.deg.ToString() + " " + lat2.deg.ToString());
            Console.WriteLine("Return Angle : " + ang.deg.ToString());
        }

        private void buttonCalcArcDistAndAngle_Click(object sender, RoutedEventArgs e)
        {
            // 지구의 특정 두지점(기준점과 임의의 지점)을 이용하여 기준점으로부터 임의의 지점까지의 방위각(Forward, Backward) 값과 지점간의 거리를 얻는다.
            // 1. 기준점 설정
            XAngle lon1 = XAngle.FromDegree(127);
            XAngle lat1 = XAngle.FromDegree(36);

            // 2. 임의의 지점 설정
            XAngle lon2 = XAngle.FromDegree(128);
            XAngle lat2 = XAngle.FromDegree(37);

            // 3. 두 지점간의 Forward, Backward각도를 얻을 객체 생성
            XAngle fwdAz = new XAngle();
            XAngle revAz = new XAngle();

            double dist = 0;

            // 4. 두지점을 입력하여 CalArcDistAndAngle함수를 이용하여 거리와 각도를 얻는다.
            bool bResult = Xfn.CalArcDistAndAngle(lon1, lat1, lon2, lat2, ref dist, ref fwdAz, ref revAz);

            Console.WriteLine("Distance : " + dist.ToString());
            Console.WriteLine("Forward Angle : " + fwdAz.deg.ToString());
            Console.WriteLine("Backward Angle : " + revAz.deg.ToString());
        }

        private void buttonGeoToECEF_Click(object sender, RoutedEventArgs e)
        {
            // Lat/Lon(위경도)좌표계로부터 ECEF좌표계로 변환하기

            // 1. 위경도 좌표값을 설정
            XGeoPoint geo = new XGeoPoint();
            XVertex3d ecr = new XVertex3d();
            geo.lond = 127;
            geo.latd = 36;
            geo.hgt = 1200;

            // 2. ECEF값을 얻는다.
            Xfn.GeoToEcr(geo, ref ecr);

            // 3. 결과값을 프린트한다.
            Console.WriteLine("X : " + ecr.x.ToString() + " Y : " + ecr.y.ToString() + " Z : " + ecr.z.ToString());
        }

        private void buttonECEFToGeo_Click(object sender, RoutedEventArgs e)
        {
            // ECEF좌표계로부터 Lat/Lon(위경도)좌표계로 변환하기
            // 1. ECEF값을 설정
            XGeoPoint geo = new XGeoPoint();
            XVertex3d ecr = new XVertex3d();
            ecr.x = -3109559.9281960232;
            ecr.y = 4126525.4002308655;
            ecr.z = 3728897.0180901629;

            // 2. 위경도값을 얻는다
            Xfn.EcrToGeo(ecr, ref geo);

            // 3. 결과값을 프린트한다.
            Console.WriteLine("Longitude : " + geo.lond.ToString() + " Latitude : " + geo.latd.ToString() + " Height : " + geo.hgt.ToString());
        }
    }
}
